@@ -15,7 +15,7 @@ our @EXPORT = qw{
 
     set_response
 
-    dsl captures capture
+    dsl captures capture stream match_lines
 
     run_swat_module apply_module_variables module_variable
 
@@ -155,6 +155,16 @@ sub captures {
     dsl()->{captures}
 }
 
+sub stream {
+
+    dsl()->{stream}
+}
+
+sub match_lines {
+
+    dsl()->{match_lines}
+}
+
 sub capture {
     dsl()->{captures}->[0]
 }
